@@ -24,6 +24,7 @@
 """Main engine responsible for extracting references from PDF documents."""
 
 import logging
+import mmap
 import re
 
 from datetime import datetime
@@ -1389,6 +1390,28 @@ def remove_leading_garbage_lines_from_reference_section(ref_sectn):
 
 # Tasks related to conversion of full-text to plain-text:
 
+def clean_pdf_file(filename):
+    """
+    strip leading and/or trailing junk from a PDF file
+    """
+    with open(filename, 'r+b') as file, mmap.mmap(file.fileno(), 0, access=mmap.ACCESS_WRITE) as mmfile:
+        start = mmfile.find(b'%PDF-')
+        if start == -1:
+            # no PDF marker found
+            LOGGER.debug('not a PDF file')
+            return
+        end = mmfile.rfind(b'%%EOF')
+        offset = len(b'%%EOF')
+        if start > 0:
+            LOGGER.debug('moving and truncating')
+            mmfile.move(0, start, end + offset - start)
+            mmfile.resize(end + offset - start)
+            mmfile.flush()
+        elif end > 0 and end + offset != mmfile.size():
+            LOGGER.debug('truncating only')
+            mmfile.resize(end + offset - start)
+            mmfile.flush()
+
 
 def get_plaintext_document_body(fpath, keep_layout=False):
     """Given a file-path to a full-text, return a list of unicode strings
@@ -1402,15 +1425,14 @@ def get_plaintext_document_body(fpath, keep_layout=False):
        @return: (list) of strings - each string being a line in the document.
     """
     textbody = []
+    clean_pdf_file(fpath)
     mime_type = magic.from_file(fpath, mime=True)
 
     if mime_type == "text/plain":
         with open(fpath, "r") as f:
             textbody = f.readlines()
-
     elif mime_type == "application/pdf":
         textbody = convert_PDF_to_plaintext(fpath, keep_layout)
-
     else:
         raise UnknownDocumentTypeError(mime_type)
 
