@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of refextract.
-# Copyright (C) 2013, 2015, 2016, 2018 CERN.
+# Copyright (C) 2013, 2015, 2016, 2018, 2020 CERN.
 #
 # refextract is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -21,11 +21,9 @@
 # granted to it by virtue of its status as an Intergovernmental Organization
 # or submit itself to any jurisdiction.
 
-from __future__ import absolute_import, division, print_function
-
 import re
 
-from urlparse import unquote
+from urllib.parse import unquote
 
 from unidecode import unidecode
 
@@ -251,19 +249,14 @@ def process_reference_line(working_line,
         previous_match = {}   # previously matched TITLE within line (used
         # for replacement of IBIDs.
         replacement_types = {}
-        journals_keys = journals_matches.keys()
-        journals_keys.sort()
-        reports_keys = pprint_repnum_matchtext.keys()
-        reports_keys.sort()
-        publishers_keys = publishers_matches.keys()
-        publishers_keys.sort()
-        spaces_keys = removed_spaces.keys()
-        spaces_keys.sort()
+        journals_keys = sorted(journals_matches.keys())
+        reports_keys = sorted(pprint_repnum_matchtext.keys())
+        publishers_keys = sorted(publishers_matches.keys())
+        spaces_keys = sorted(removed_spaces.keys())
         replacement_types = get_replacement_types(journals_keys,
                                                   reports_keys,
                                                   publishers_keys)
-        replacement_locations = replacement_types.keys()
-        replacement_locations.sort()
+        replacement_locations = sorted(replacement_types.keys())
 
         tagged_line = u""  # This is to be the new 'working-line'. It will
         # contain the tagged TITLEs and REPORT-NUMBERs,
@@ -344,7 +337,7 @@ def wash_volume_tag(line):
 
 def tag_isbn(line):
     """Tag books ISBN"""
-    return re_isbn.sub(ur'<cds.ISBN>\g<code></cds.ISBN>', line)
+    return re_isbn.sub(r'<cds.ISBN>\g<code></cds.ISBN>', line)
 
 
 def tag_quoted_text(line):
@@ -354,7 +347,7 @@ def tag_quoted_text(line):
     associate we record.
     We also use titles for recognising books.
     """
-    return re_quoted.sub(ur'<cds.QUOTED>\g<title></cds.QUOTED>', line)
+    return re_quoted.sub(r'<cds.QUOTED>\g<title></cds.QUOTED>', line)
 
 
 def tag_arxiv(line):
@@ -391,10 +384,10 @@ def tag_arxiv_more(line):
     * hep-th/1234567
     * arXiv:1022111 [hep-ph] which transforms to hep-ph/1022111
     """
-    line = RE_ARXIV_CATCHUP.sub(ur"\g<suffix>/\g<year>\g<month>\g<num>", line)
+    line = RE_ARXIV_CATCHUP.sub(r"\g<suffix>/\g<year>\g<month>\g<num>", line)
 
     for report_re, report_repl in RE_OLD_ARXIV:
-        report_number = report_repl + ur"/\g<num>"
+        report_number = report_repl + r"/\g<num>"
         line = report_re.sub(
             u'<cds.ARXIV>' + report_number + u'</cds.ARXIV>',
             line
@@ -438,9 +431,9 @@ def tag_pos_volume(line):
 
 def tag_atlas_conf(line):
     line = RE_ATLAS_CONF_PRE_2010.sub(
-        ur'<cds.REPORTNUMBER>ATL-CONF-\g<code></cds.REPORTNUMBER>', line)
+        r'<cds.REPORTNUMBER>ATL-CONF-\g<code></cds.REPORTNUMBER>', line)
     line = RE_ATLAS_CONF_POST_2010.sub(
-        ur'<cds.REPORTNUMBER>ATLAS-CONF-\g<code></cds.REPORTNUMBER>', line)
+        r'<cds.REPORTNUMBER>ATLAS-CONF-\g<code></cds.REPORTNUMBER>', line)
     return line
 
 
@@ -849,7 +842,7 @@ def strip_tags(line):
     # author content can be checked for underscores later on
     # Note that we don't have embedded tags this is why
     # we can do this
-    re_tag = re.compile(ur'<cds\.[A-Z]+>[^<]*</cds\.[A-Z]+>|<cds\.[A-Z]+ />',
+    re_tag = re.compile(r'<cds\.[A-Z]+>[^<]*</cds\.[A-Z]+>|<cds\.[A-Z]+ />',
                         re.UNICODE)
     for m in re_tag.finditer(line):
         chars_count = m.end() - m.start()
@@ -868,7 +861,7 @@ def identify_and_tag_collaborations(line, collaborations_kb):
        which won't influence the reference splitting heuristics
        (used when looking at mulitple <AUTH> tags in a line).
     """
-    for dummy_collab, re_collab in collaborations_kb.iteritems():
+    for dummy_collab, re_collab in collaborations_kb.items():
         matches = re_collab.finditer(strip_tags(line))
 
         for match in reversed(list(matches)):
@@ -1236,9 +1229,7 @@ def identify_report_numbers(line, kb_reports):
     # at given locations in line
 
     repnum_search_kb, repnum_standardised_categs = kb_reports
-    repnum_categs = repnum_standardised_categs.keys()
-    repnum_categs.sort(_by_len)
-
+    repnum_categs = sorted(repnum_standardised_categs.keys(), key=lambda x: (len(x[1]), x), reverse=True)
     # Handle CERN/LHCC/98-013
     line = line.replace('/', ' ')
 
@@ -1284,7 +1275,7 @@ def identify_publishers(line, kb_publishers):
     matches_repl = {}  # standardised report numbers matched
     # at given locations in line
 
-    for abbrev, info in kb_publishers.iteritems():
+    for abbrev, info in kb_publishers.items():
         for match in info['pattern'].finditer(line):
             # record the matched non-standard version of the publisher:
             matches_repl[match.start(0)] = abbrev
@@ -1377,17 +1368,14 @@ def identify_and_tag_URLs(line):
 
     # Now that all URLs have been identified, insert them
     # back into the line, tagged:
-    found_url_positions = found_url_urlstring.keys()
-    found_url_positions.sort()
-    found_url_positions.reverse()
+    found_url_positions = sorted(found_url_urlstring.keys(), reverse=True)
     for url_position in found_url_positions:
         line = line[0:url_position] + "<cds.URL />" \
             + line[url_position + found_url_full_matchlen[url_position]:]
 
     # The line has been rebuilt. Now record the information about the
     # matched URLs:
-    found_url_positions = found_url_urlstring.keys()
-    found_url_positions.sort()
+    found_url_positions = sorted(found_url_urlstring.keys())
     for url_position in found_url_positions:
         identified_urls.append((found_url_urlstring[url_position],
                                 found_url_urldescr[url_position]))
